@@ -1,5 +1,5 @@
 from trame.app import get_server, jupyter
-from vera_core.app import engine, ui
+from vera_core.app import ui
 
 from .core.vera_out_file import VeraOutFile
 
@@ -15,16 +15,9 @@ def show(data=None, server=None, **kwargs):
     if isinstance(server, str):
         server = get_server(server)
 
-    # Disable logging
-    import logging
-
-    engine_logger = logging.getLogger("vera_core.app.engine")
-    engine_logger.setLevel(logging.WARNING)
-
     vera_out_file = VeraOutFile(data)
 
     # Initialize app
-    engine.initialize(server)
     ui.initialize(server, vera_out_file)
 
     # Show as cell result
